@@ -1,4 +1,4 @@
-/* misc.h -- functions used by contact_list/uconfig
+/* misc.h -- miscellaneous functions
    Copyright (C) 2004 Julio A. Becerra
 
    This program is free software; you can redistribute it and/or
@@ -20,6 +20,7 @@
 #define MISC_H
 
 #include <unistd.h>
+#include "common.h"
 
 #define ERR_C (ERR_LOCAL -1)
 #define ERR_SIZE (ERR_LOCAL -2)
@@ -31,5 +32,6 @@ extern char *home_path (char *file);
 extern int read_tag (int fd, char *src, char *name, char *buff, size_t size);
 extern int write_tag (int fd, char *name, char *buff, size_t tabs);
 extern int check_dir ();
+extern char *ipv4_to_string (ip_t ip);
 
 #endif
