@@ -18,10 +18,9 @@
 
 #define _POSIX_SOURCE
 
-#include <stdio.h>		/* sprintf */
 #include <unistd.h>		/* read, write, close */
 #include <stdlib.h>		/* malloc, realloc, free */
-#include <string.h>		/* memcpy, memmove */
+#include <string.h>		/* memcpy, memmove, strcpy */
 #include <netdb.h>		/* gethostbyname */
 #include <netinet/in.h>		/* ntohl, *HTON, *NTOH */
 #include <errno.h>		/* errno */
@@ -33,6 +32,7 @@
 #include "tcp.h"
 #include "contact_list.h"
 #include "protocol.h"
+#include "misc.h"
 
 extern int errno;
 
@@ -53,7 +53,6 @@ static int recv_msg (contact_t *c);
 static int net_read (int fd, void *buf, size_t nbytes);
 static void send_or_postpone (contact_t *contact);
 static contact_t *create_temp_contact (ip_t ip);
-static void ipv4_to_string (char *dest, ip_t ip);
 static void create_hello_timeout (contact_t *c);
 static void cb_hello_timeout (void *data);
 static BYTE *inc_out_buffer (contact_t *contact, int bytes);
@@ -246,15 +245,15 @@ cb_server_data (int fd, void *data)
 
 	c = cl_find_by_ip (ip); /* TODO in the future, find by public key */
 
-	if (!c || c->state.socket >= 0) {
-		if (c) {
-			ui_output_info ("%s reconnected, closing old "
-			                "connection.",  c->nick);
-			tr_disconnect (c);
-		}
+	if (!c) {
 		c = create_temp_contact (ip);
 		CHECK (c);
 	}
+	else if (c->state.socket >= 0) {
+		ui_output_info ("%s reconnected, closing old connection.",
+		                c->nick);
+		tr_disconnect (c);
+	}
 
 	c->state.socket = s;
 	c->state.hello_pending = TRUE; /* TODO it should already be, check it */
@@ -438,7 +437,7 @@ create_temp_contact (ip_t ip)
 	c = malloc (sizeof (contact_t));
 	CHECK_J (c, end);
 
-	ipv4_to_string (c->hname, ip);
+	strcpy (c->hname, ipv4_to_string (ip));
 	c->port = 0;
 	c->nick[0] = '\0';
 	c->next = NULL;
@@ -458,14 +457,6 @@ end:
 	return c;
 }
 
-/* 'dest' must have at least 16 bytes */
-static void
-ipv4_to_string (char *dest, ip_t ip)
-{
-	BYTE *p = (BYTE *)&ip;
-	sprintf (dest, "%u.%u.%u.%u", p[3], p[2], p[1], p[0]);
-}
-
 static void
 create_hello_timeout (contact_t *c)
 {
@@ -477,10 +468,8 @@ create_hello_timeout (contact_t *c)
 static void
 cb_hello_timeout (void *data)
 {
-	char s[16];
-
-	ipv4_to_string (s, ((contact_t *)data)->state.ip);
-	ui_output_info ("Someone from %s connected and didn't say hello!", s);
+	ui_output_info ("Someone from %s connected and didn't say hello!",
+	                ipv4_to_string (((contact_t *)data)->state.ip));
 	tr_disconnect ((contact_t *)data);
 }
 
@@ -511,11 +500,16 @@ cb_resolv (void *data)
 	/* TODO if pthreads are available, use them so the program
 	   doesn't block while we resolv (or use libadns) */
 
-	ui_output_info ("Resolving hostnames...");  /* TODO desactivable */
+/* TODO this should be a configurable setting */
+#ifdef IPCHAT_VERBOSE
+	ui_output_info ("Resolving hostnames...");
+#endif
 	for (c = contacts; c; c = c->next) {
 		tr_resolv (c);
 	}
+#ifdef IPCHAT_VERBOSE
 	ui_output_info ("Resolving done.");
+#endif
 }
 
 /* Try to connect to all disconnected contacts. */
